<?php
/**
 * app/plugins/dnd/controllers/admin/skills.php
 *
 * This is the skills admin controller.
 *
 * @package TTE Dungeons & Dragons
 * @version 3.0
 * @author  Joey Kimsey <Joey@tabletopelite.com>
 * @link    https://TableTopElite.com
 */
namespace TheTempusProject\Controllers\Admin;

use TheTempusProject\Houdini\Classes\Issues;
use TheTempusProject\Houdini\Classes\Views;
use TheTempusProject\Houdini\Classes\Components;
use TheTempusProject\Bedrock\Functions\Input;
use TheTempusProject\Bedrock\Functions\Check;
use TheTempusProject\Classes\Forms;
use TheTempusProject\Classes\AdminController;
use TheTempusProject\Models\Skills as SkillsModel;
use TheTempusProject\Houdini\Classes\Forms as HoudiniForms;

class Skills extends AdminController {
    protected static $skills;

    public function __construct() {
        parent::__construct();
        self::$title = 'Admin - D&D Skills';
        self::$skills = new SkillsModel;
    }

    public function index( $data = null ) {
        Views::view( 'dnd.admin.skills.list', self::$skills->list() );
    }

    public function view( $id = null ) {
        $data = self::$skills->findById( $id );
        if ( $data == false ) {
            Issues::add( 'error', 'Skill not found.' );
            return $this->index();
        }
        Views::view( 'dnd.admin.skills.view', $data );
    }

    public function create( $data = null ) {
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown') );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown') );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', 'none', self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            Views::view( 'dnd.admin.skills.create' );
        }
        if ( !Forms::check( 'createSkill' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.skills.create' );
        }
        if ( self::$skills->create( Input::post( 'name' )) ) {
            Issues::add( 'success', 'Skill created' );
            return $this->index();
        } else {
            Issues::add( 'error', 'There was an error creating your skill.' );
            return Views::view( 'dnd.admin.skills.create' );
        }
    }

    public function edit( $id = null ) {
        $data = self::$skills->findById( $id );
        if ( false == $data ) {
            return $this->index();
        }
        Components::set( 'privacyDropdown', Views::simpleView('dnd.forms.privacyDropdown', $data) );
        Components::set( 'versionDropdown', Views::simpleView('dnd.forms.versionDropdown', $data) );
        $sourcebookSelect = HoudiniForms::getFormFieldHtml( 'sourcebookID', 'SourceBook', 'select', $data->sourcebookID, self::$sourcebooks->simpleList() );
        Components::set( 'sourcebookSelect', $sourcebookSelect );
        if ( !Input::exists( 'submit' ) ) {
            return Views::view( 'dnd.admin.skills.edit', $data );
        }
        if ( !Forms::check( 'editSkill' ) ) {
            Issues::add( 'error', [ 'There was an error with your request.' => Check::userErrors() ] );
            return Views::view( 'dnd.admin.skills.edit', $data );
        }
        if ( self::$skills->update( $id, Input::post( 'title' ), Input::post( 'suggestion' ), Input::post( 'approved' ) ) ) {
            Issues::add( 'success', 'Skill updated' );
        } else {
            return Views::view( 'dnd.admin.skills.edit', $data );
        }
    }

    public function delete( $data = null ) {
        if ( Input::exists( 'submit' ) ) {
            $data = Input::post( 'SK_' );
        }
        if ( !self::$skills->delete( $data ) ) {
            Issues::add( 'error', 'There was an error with your request.' );
        } else {
            Issues::add( 'success', 'Skill has been deleted' );
        }
        $this->index();
    }
}
